@@ -24,8 +24,6 @@
 #endif
 
 #include <gst/gl/gl.h>
-
-#include "gstglelements.h"
 #include "gstglcolorconvertelement.h"
 
 GST_DEBUG_CATEGORY_STATIC (gst_gl_color_convert_element_debug);
@@ -37,17 +35,16 @@ G_DEFINE_TYPE_WITH_CODE (GstGLColorConvertElement, gst_gl_color_convert_element,
     GST_DEBUG_CATEGORY_INIT (gst_gl_color_convert_element_debug,
         "glconvertelement", 0, "convert");
     );
-GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (glcolorconvert, "glcolorconvert",
-    GST_RANK_NONE, GST_TYPE_GL_COLOR_CONVERT_ELEMENT, gl_element_init (plugin));
 
-static gboolean gst_gl_color_convert_element_gl_set_caps (GstGLBaseFilter *
-    base_filter, GstCaps * in_caps, GstCaps * out_caps);
+static gboolean gst_gl_color_convert_element_set_caps (GstBaseTransform * bt,
+    GstCaps * in_caps, GstCaps * out_caps);
 static GstCaps *gst_gl_color_convert_element_transform_caps (GstBaseTransform *
     bt, GstPadDirection direction, GstCaps * caps, GstCaps * filter);
 static gboolean gst_gl_color_convert_element_get_unit_size (GstBaseTransform *
     trans, GstCaps * caps, gsize * size);
-static gboolean gst_gl_color_convert_element_filter_meta (GstBaseTransform *
-    trans, GstQuery * query, GType api, const GstStructure * params);
+static gboolean
+gst_gl_color_convert_element_filter_meta (GstBaseTransform * trans,
+    GstQuery * query, GType api, const GstStructure * params);
 static gboolean gst_gl_color_convert_element_decide_allocation (GstBaseTransform
     * trans, GstQuery * query);
 static GstFlowReturn
@@ -55,11 +52,8 @@ gst_gl_color_convert_element_prepare_output_buffer (GstBaseTransform * bt,
     GstBuffer * inbuf, GstBuffer ** outbuf);
 static GstFlowReturn gst_gl_color_convert_element_transform (GstBaseTransform *
     bt, GstBuffer * inbuf, GstBuffer * outbuf);
-static GstCaps *gst_gl_color_convert_element_fixate_caps (GstBaseTransform * bt,
-    GstPadDirection direction, GstCaps * caps, GstCaps * othercaps);
-static gboolean
-gst_gl_color_convert_transform_meta (GstBaseTransform * bt,
-    GstBuffer * outbuf, GstMeta * meta, GstBuffer * inbuf);
+static GstCaps *gst_gl_color_convert_element_fixate_caps (GstBaseTransform *
+    bt, GstPadDirection direction, GstCaps * caps, GstCaps * othercaps);
 static GstStateChangeReturn
 gst_gl_color_convert_element_change_state (GstElement * element,
     GstStateChange transition);
@@ -76,35 +70,35 @@ GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS (GST_GL_COLOR_CONVERT_VIDEO_CAPS));
 
-static void
-gst_gl_color_convert_element_gl_stop (GstGLBaseFilter * filter)
+static gboolean
+gst_gl_color_convert_element_stop (GstBaseTransform * bt)
 {
-  GstGLColorConvertElement *convert = GST_GL_COLOR_CONVERT_ELEMENT (filter);
+  GstGLColorConvertElement *convert = GST_GL_COLOR_CONVERT_ELEMENT (bt);
 
   if (convert->convert) {
     gst_object_unref (convert->convert);
     convert->convert = NULL;
   }
 
-  GST_GL_BASE_FILTER_CLASS (parent_class)->gl_stop (filter);
+  return GST_BASE_TRANSFORM_CLASS (parent_class)->stop (bt);
 }
 
 static void
 gst_gl_color_convert_element_class_init (GstGLColorConvertElementClass * klass)
 {
-  GstGLBaseFilterClass *filter_class = GST_GL_BASE_FILTER_CLASS (klass);
   GstBaseTransformClass *bt_class = GST_BASE_TRANSFORM_CLASS (klass);
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   bt_class->transform_caps = gst_gl_color_convert_element_transform_caps;
+  bt_class->set_caps = gst_gl_color_convert_element_set_caps;
   bt_class->get_unit_size = gst_gl_color_convert_element_get_unit_size;
   bt_class->filter_meta = gst_gl_color_convert_element_filter_meta;
   bt_class->decide_allocation = gst_gl_color_convert_element_decide_allocation;
   bt_class->prepare_output_buffer =
       gst_gl_color_convert_element_prepare_output_buffer;
   bt_class->transform = gst_gl_color_convert_element_transform;
+  bt_class->stop = gst_gl_color_convert_element_stop;
   bt_class->fixate_caps = gst_gl_color_convert_element_fixate_caps;
-  bt_class->transform_meta = gst_gl_color_convert_transform_meta;
 
   bt_class->passthrough_on_same_caps = TRUE;
 
@@ -115,13 +109,10 @@ gst_gl_color_convert_element_class_init (GstGLColorConvertElementClass * klass)
   gst_element_class_add_static_pad_template (element_class,
       &gst_gl_color_convert_element_sink_pad_template);
 
-  gst_element_class_set_static_metadata (element_class,
+  gst_element_class_set_metadata (element_class,
       "OpenGL color converter", "Filter/Converter/Video",
       "Converts between color spaces using OpenGL shaders",
       "Matthew Waters <matthew@centricular.com>");
-
-  filter_class->gl_stop = gst_gl_color_convert_element_gl_stop;
-  filter_class->gl_set_caps = gst_gl_color_convert_element_gl_set_caps;
 }
 
 static void
@@ -132,14 +123,10 @@ gst_gl_color_convert_element_init (GstGLColorConvertElement * convert)
 }
 
 static gboolean
-gst_gl_color_convert_element_gl_set_caps (GstGLBaseFilter * base_filter,
+gst_gl_color_convert_element_set_caps (GstBaseTransform * bt,
     GstCaps * in_caps, GstCaps * out_caps)
 {
-  GstGLColorConvertElement *convert =
-      GST_GL_COLOR_CONVERT_ELEMENT (base_filter);
-
-  if (!convert->convert && base_filter->context)
-    convert->convert = gst_gl_color_convert_new (base_filter->context);
+  GstGLColorConvertElement *convert = GST_GL_COLOR_CONVERT_ELEMENT (bt);
 
   if (!gst_gl_color_convert_set_caps (convert->convert, in_caps, out_caps))
     return FALSE;
@@ -154,21 +141,16 @@ gst_gl_color_convert_element_transform_caps (GstBaseTransform * bt,
   GstGLColorConvertElement *convert = GST_GL_COLOR_CONVERT_ELEMENT (bt);
   GstGLBaseFilter *base_filter = GST_GL_BASE_FILTER (bt);
   GstGLContext *context;
-  GstCaps *ret;
 
   if (base_filter->display && !gst_gl_base_filter_find_gl_context (base_filter))
-    return gst_caps_new_empty ();
+    return NULL;
 
-  context = gst_gl_base_filter_get_gl_context (base_filter);
+  context = GST_GL_BASE_FILTER (bt)->context;
 
   if (!convert->convert && context)
     convert->convert = gst_gl_color_convert_new (context);
 
-  ret = gst_gl_color_convert_transform_caps (context, direction, caps, filter);
-
-  gst_clear_object (&context);
-
-  return ret;
+  return gst_gl_color_convert_transform_caps (context, direction, caps, filter);
 }
 
 static gboolean
@@ -250,31 +232,6 @@ gst_gl_color_convert_element_transform (GstBaseTransform * bt,
   return GST_FLOW_OK;
 }
 
-static gboolean
-gst_gl_color_convert_transform_meta (GstBaseTransform * bt,
-    GstBuffer * outbuf, GstMeta * meta, GstBuffer * inbuf)
-{
-  const GstMetaInfo *info = meta->info;
-  gboolean should_copy = TRUE;
-  const gchar *valid_tags[] = {
-    GST_META_TAG_VIDEO_STR,
-    GST_META_TAG_VIDEO_ORIENTATION_STR,
-    GST_META_TAG_VIDEO_SIZE_STR,
-    NULL
-  };
-
-  should_copy = gst_meta_api_type_tags_contain_only (info->api, valid_tags);
-
-  /* Cant handle the tags in this meta, let the parent class handle it */
-  if (!should_copy) {
-    return GST_BASE_TRANSFORM_CLASS (parent_class)->transform_meta (bt,
-        outbuf, meta, inbuf);
-  }
-
-  /* No need to transform, we can safely copy this meta */
-  return TRUE;
-}
-
 static GstCaps *
 gst_gl_color_convert_element_fixate_caps (GstBaseTransform *
     bt, GstPadDirection direction, GstCaps * caps, GstCaps * othercaps)
@@ -292,8 +249,8 @@ gst_gl_color_convert_element_change_state (GstElement * element,
   GstStateChangeReturn ret = GST_STATE_CHANGE_SUCCESS;
 
   GST_DEBUG_OBJECT (convert, "changing state: %s => %s",
-      gst_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
-      gst_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
+      gst_element_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
+      gst_element_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
 
   ret = GST_ELEMENT_CLASS (parent_class)->change_state (element, transition);
   if (ret == GST_STATE_CHANGE_FAILURE)
