@@ -137,10 +137,6 @@
 GST_DEBUG_CATEGORY_STATIC (gst_audio_encoder_debug);
 #define GST_CAT_DEFAULT gst_audio_encoder_debug
 
-#define GST_AUDIO_ENCODER_GET_PRIVATE(obj)  \
-    (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GST_TYPE_AUDIO_ENCODER, \
-        GstAudioEncoderPrivate))
-
 enum
 {
   PROP_0,
@@ -247,6 +243,7 @@ struct _GstAudioEncoderPrivate
 
 
 static GstElementClass *parent_class = NULL;
+static gint private_offset = 0;
 
 static void gst_audio_encoder_class_init (GstAudioEncoderClass * klass);
 static void gst_audio_encoder_init (GstAudioEncoder * parse,
@@ -278,12 +275,22 @@ gst_audio_encoder_get_type (void)
     audio_encoder_type = g_type_register_static (GST_TYPE_ELEMENT,
         "GstAudioEncoder", &audio_encoder_info, G_TYPE_FLAG_ABSTRACT);
 
+    private_offset =
+        g_type_add_instance_private (audio_encoder_type,
+        sizeof (GstAudioEncoderPrivate));
+
     g_type_add_interface_static (audio_encoder_type, GST_TYPE_PRESET,
         &preset_interface_info);
   }
   return audio_encoder_type;
 }
 
+static inline GstAudioEncoderPrivate *
+gst_audio_encoder_get_instance_private (GstAudioEncoder * self)
+{
+  return (G_STRUCT_MEMBER_P (self, private_offset));
+}
+
 static void gst_audio_encoder_finalize (GObject * object);
 static void gst_audio_encoder_reset (GstAudioEncoder * enc, gboolean full);
 
@@ -345,7 +352,8 @@ gst_audio_encoder_class_init (GstAudioEncoderClass * klass)
   GST_DEBUG_CATEGORY_INIT (gst_audio_encoder_debug, "audioencoder", 0,
       "audio encoder base class");
 
-  g_type_class_add_private (klass, sizeof (GstAudioEncoderPrivate));
+  if (private_offset != 0)
+    g_type_class_adjust_private_offset (klass, &private_offset);
 
   gobject_class->set_property = gst_audio_encoder_set_property;
   gobject_class->get_property = gst_audio_encoder_get_property;
@@ -392,7 +400,7 @@ gst_audio_encoder_init (GstAudioEncoder * enc, GstAudioEncoderClass * bclass)
 
   GST_DEBUG_OBJECT (enc, "gst_audio_encoder_init");
 
-  enc->priv = GST_AUDIO_ENCODER_GET_PRIVATE (enc);
+  enc->priv = gst_audio_encoder_get_instance_private (enc);
 
   /* only push mode supported */
   pad_template =
@@ -720,7 +728,7 @@ foreach_metadata (GstBuffer * inbuf, GstMeta ** meta, gpointer user_data)
  * are considered discarded, e.g. as a result of discontinuous transmission,
  * and a discontinuity is marked.
  *
- * Note that samples received in gst_audio_encoder_handle_frame()
+ * Note that samples received in #GstAudioEncoderClass.handle_frame()
  * may be invalidated by a call to this function.
  *
  * Returns: a #GstFlowReturn that should be escalated to caller (of caller)
@@ -1325,7 +1333,18 @@ gst_audio_encoder_chain (GstPad * pad, GstObject * parent, GstBuffer * buffer)
     }
     if (discont) {
       /* now re-sync ts */
-      priv->base_ts += diff;
+      GstClockTime shift =
+          gst_util_uint64_scale (gst_adapter_available (priv->adapter),
+          GST_SECOND, ctx->info.rate * ctx->info.bpf);
+
+      if (G_UNLIKELY (shift > GST_BUFFER_TIMESTAMP (buffer))) {
+        /* ERROR */
+        goto wrong_time;
+      }
+      /* arrange for newly added samples to come out with the ts
+       * of the incoming buffer that adds these */
+      priv->base_ts = GST_BUFFER_TIMESTAMP (buffer) - shift;
+      priv->samples = 0;
       gst_audio_encoder_set_base_gp (enc);
       priv->discont |= discont;
     }
@@ -1362,6 +1381,14 @@ wrong_buffer:
     ret = GST_FLOW_ERROR;
     goto done;
   }
+wrong_time:
+  {
+    GST_ELEMENT_ERROR (enc, STREAM, ENCODE, (NULL),
+        ("buffer going too far back in time"));
+    gst_buffer_unref (buffer);
+    ret = GST_FLOW_ERROR;
+    goto done;
+  }
 }
 
 static gboolean
@@ -2129,7 +2156,7 @@ gst_audio_encoder_get_audio_info (GstAudioEncoder * enc)
  * must be called with the same number.
  *
  * Note: This value will be reset to 0 every time before
- * GstAudioEncoder::set_format() is called.
+ * #GstAudioEncoderClass.set_format() is called.
  */
 void
 gst_audio_encoder_set_frame_samples_min (GstAudioEncoder * enc, gint num)
@@ -2166,7 +2193,7 @@ gst_audio_encoder_get_frame_samples_min (GstAudioEncoder * enc)
  * must be called with the same number.
  *
  * Note: This value will be reset to 0 every time before
- * GstAudioEncoder::set_format() is called.
+ * #GstAudioEncoderClass.set_format() is called.
  */
 void
 gst_audio_encoder_set_frame_samples_max (GstAudioEncoder * enc, gint num)
@@ -2200,7 +2227,7 @@ gst_audio_encoder_get_frame_samples_max (GstAudioEncoder * enc)
  * Requires @frame_samples_min and @frame_samples_max to be the equal.
  *
  * Note: This value will be reset to 0 every time before
- * GstAudioEncoder::set_format() is called.
+ * #GstAudioEncoderClass.set_format() is called.
  */
 void
 gst_audio_encoder_set_frame_max (GstAudioEncoder * enc, gint num)
@@ -2233,7 +2260,7 @@ gst_audio_encoder_get_frame_max (GstAudioEncoder * enc)
  * Sets encoder lookahead (in units of input rate samples)
  *
  * Note: This value will be reset to 0 every time before
- * GstAudioEncoder::set_format() is called.
+ * #GstAudioEncoderClass.set_format() is called.
  */
 void
 gst_audio_encoder_set_lookahead (GstAudioEncoder * enc, gint num)
@@ -2781,7 +2808,7 @@ gst_audio_encoder_negotiate_unlocked (GstAudioEncoder * enc)
  * Unmark GST_PAD_FLAG_NEED_RECONFIGURE in any case. But mark it again if
  * negotiate fails.
  *
- * Returns: #TRUE if the negotiation succeeded, else #FALSE.
+ * Returns: %TRUE if the negotiation succeeded, else %FALSE.
  */
 gboolean
 gst_audio_encoder_negotiate (GstAudioEncoder * enc)
@@ -2908,7 +2935,7 @@ fallback:
  * @allocator: (out) (allow-none) (transfer full): the #GstAllocator
  * used
  * @params: (out) (allow-none) (transfer full): the
- * #GstAllocatorParams of @allocator
+ * #GstAllocationParams of @allocator
  *
  * Lets #GstAudioEncoder sub-classes to know the memory @allocator
  * used by the base class and its @params.
