@@ -26,7 +26,7 @@
 G_BEGIN_DECLS
 
 #define GST_TYPE_GL_BUFFER_ALLOCATOR (gst_gl_buffer_allocator_get_type())
-GST_EXPORT
+GST_GL_API
 GType gst_gl_buffer_allocator_get_type(void);
 
 #define GST_IS_GL_BUFFER_ALLOCATOR(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_GL_ALLOCATOR))
@@ -57,7 +57,7 @@ struct _GstGLBuffer
 typedef struct _GstGLBufferAllocationParams GstGLBufferAllocationParams;
 
 #define GST_TYPE_GL_BUFFER_ALLOCATION_PARAMS (gst_gl_buffer_allocation_params_get_type())
-GST_EXPORT
+GST_GL_API
 GType gst_gl_buffer_allocation_params_get_type (void);
 
 /**
@@ -84,7 +84,7 @@ struct _GstGLBufferAllocationParams
   gpointer                  _padding[GST_PADDING];
 };
 
-GST_EXPORT
+GST_GL_API
 GstGLBufferAllocationParams *   gst_gl_buffer_allocation_params_new     (GstGLContext * context,
                                                                          gsize alloc_size,
                                                                          GstAllocationParams * alloc_params,
@@ -92,9 +92,9 @@ GstGLBufferAllocationParams *   gst_gl_buffer_allocation_params_new     (GstGLCo
                                                                          guint gl_usage);
 
 /**
- * GstGLBufferAllocator
+ * GstGLBufferAllocator:
  *
- * Opaque #GstGLAllocator struct
+ * Opaque #GstGLBufferAllocator struct
  */
 struct _GstGLBufferAllocator
 {
@@ -131,9 +131,9 @@ struct _GstGLBufferAllocatorClass
  */
 #define GST_GL_BUFFER_ALLOCATOR_NAME   "GLBuffer"
 
-GST_EXPORT
+GST_GL_API
 void          gst_gl_buffer_init_once (void);
-GST_EXPORT
+GST_GL_API
 gboolean      gst_is_gl_buffer        (GstMemory * mem);
 
 G_END_DECLS
