@@ -26,6 +26,12 @@
 #include <gst/video/video.h>
 #include "gstvideoutils.h"
 
+/**
+ * SECTION:gstvideoutils
+ * @title: GstVideo Codec utility function
+ * @short_description: Extra utility functions for video codecs
+ */
+
 #include <string.h>
 
 G_DEFINE_BOXED_TYPE (GstVideoCodecFrame, gst_video_codec_frame,
@@ -162,6 +168,8 @@ _gst_video_codec_state_free (GstVideoCodecState * state)
 
   if (state->caps)
     gst_caps_unref (state->caps);
+  if (state->allocation_caps)
+    gst_caps_unref (state->allocation_caps);
   if (state->codec_data)
     gst_buffer_unref (state->codec_data);
   g_slice_free (GstVideoCodecState, state);
