@@ -182,6 +182,27 @@ static SubParseInputChunk srt_input4[] = {
   ,
 };
 
+/* Test broken timestamp */
+static SubParseInputChunk srt_input5[] = {
+  {
+        "1\n00:00:01,000 --> 00:00:02,000\n<v>some text\n\n",
+      1 * GST_SECOND, 2 * GST_SECOND, "some text"}
+  ,
+  {
+        "2\n00:02:00,000 --> 00:03:0\n<v>some other text\n\n3\n00:00:03,000 --> 00:00:04,000\n<v>some more text\n\n",
+      3 * GST_SECOND, 4 * GST_SECOND, "some more text"}
+  ,
+};
+
+/* Test with no newline at the end */
+static SubParseInputChunk srt_input6[] = {
+  {
+        "1\n00:00:01,000 --> 00:00:02,000\nLast cue, no newline at the end",
+      1 * GST_SECOND, 2 * GST_SECOND, "Last cue, no newline at the end"}
+  ,
+};
+
+
 static void
 setup_subparse (void)
 {
@@ -374,6 +395,12 @@ GST_START_TEST (test_srt)
 
   /* try with some WebVTT chunks */
   test_srt_do_test (srt_input4, 0, G_N_ELEMENTS (srt_input4));
+
+  /* try with some broken/cut-off timestamp */
+  test_srt_do_test (srt_input5, 0, G_N_ELEMENTS (srt_input5));
+
+  /* try without an empty line at the end */
+  test_srt_do_test (srt_input6, 0, G_N_ELEMENTS (srt_input6));
 }
 
 GST_END_TEST;
@@ -460,7 +487,17 @@ GST_START_TEST (test_webvtt)
         2 * GST_SECOND, 3 * GST_SECOND, "Hello\nWorld"}
     ,
   };
+
+  /* Test with no newline at the end */
+  SubParseInputChunk webvtt_input2[] = {
+    {
+          "1\n00:00:01,000 --> 00:00:02,000\nLast cue, no newline at the end",
+        1 * GST_SECOND, 2 * GST_SECOND, "Last cue, no newline at the end"}
+    ,
+  };
+
   test_vtt_do_test (webvtt_input, 0, G_N_ELEMENTS (webvtt_input));
+  test_vtt_do_test (webvtt_input2, 0, G_N_ELEMENTS (webvtt_input2));
 }
 
 GST_END_TEST;
